@@ -1,24 +1,30 @@
-# Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+
 
-from wb import DefineModule, wbinputs
-import grt
 import os
 import sys
+from wb import DefineModule, wbinputs
+import grt
+
 
 from mforms import Utilities, newButton, newLabel, newBox
 import mforms
@@ -26,7 +32,6 @@ import mforms
 import wb_admin_main
 import wb_admin_utils
 import wba_ssh_ui
-import wb_admin_ssh
 import wb_admin_control
 from wb_server_control import PasswordHandler
 from wb_server_control import ServerProfile
@@ -69,7 +74,7 @@ from workbench.log import log_info, log_warning, log_error, log_debug, log_debug
 
 
 # define this Python module as a GRT module
-ModuleInfo = DefineModule(name= "WbAdmin", author= "Oracle Corp.", version="2.0")
+ModuleInfo = DefineModule(name="WbAdmin", author="Oracle Corp.", version="2.0")
 
 class DBError(Exception):
     pass
@@ -108,7 +113,7 @@ class AdministratorContext:
 
         self.sidebar.add_on_section_command_callback(self._sidebar_entry_clicked)
 
-        self.sidebar_sections = [("wba_management", "MANAGEMENT", []), ("wba_instance", "INSTANCE", []),  ("wba_performance", "PERFORMANCE", [])]
+        self.sidebar_sections = [("Management", "Management", "MANAGEMENT", []), ("Instance", "Instance", "INSTANCE", []), ("Performance", "Performance", "PERFORMANCE", [])]
 
         self.shown_in_sidebar = False
 
@@ -173,10 +178,6 @@ class AdministratorContext:
                 self.ctrl_be.acquire_admin_access()
                 mforms.App.get().set_status_text("Management support for target host enabled successfully.")
                 return True
-            except wb_admin_ssh.ConnectionError, exc:
-                self.admin_access_status = "Remote management capabilities are currently unavailable.\nSSH connection could not be established\n\n%s" % str(exc)
-                Utilities.show_error("Error opening SSH connection to server (%s@%s)" % (self.instance_profile.loginInfo["ssh.userName"], self.instance_profile.loginInfo["ssh.hostName"]), str(exc), "OK", "", "")
-                return None
             except OperationCancelledError, exc:
                 self.admin_access_status = "Remote management capabilities are currently unavailable.\nSSH connection was cancelled"
                 mforms.App.get().set_status_text("Cancelled SSH connection (%s)"%exc)
@@ -328,8 +329,8 @@ class AdministratorContext:
             self.page_instances[entry_id] = page
             self.admin_tab.add_page(page)
 
-        for sname, stitle, sitems in self.sidebar_sections:
-            for ident, title, icon_path in sitems:
+        for sname, saname, stitle, sitems in self.sidebar_sections:
+            for ident, ianame, title, icon_path in sitems:
                 if ident == entry_id:
                     self.admin_tab.set_content_label("Administration - %s" % title)
                     break
@@ -337,22 +338,22 @@ class AdministratorContext:
         self.admin_tab.select_page(page)
 
 
-    def add_section(self, name, title):
+    def add_section(self, name, accessibilityName, title):
         if not any(x[0] == name for x in self.sidebar_sections):
-            self.sidebar_sections.append((name, title, []))
+            self.sidebar_sections.append((name, accessibilityName, title, []))
 
 
-    def register_page(self, page_class, section_id, title, needs_remote_access = False):
+    def register_page(self, page_class, section_id, title, accessibilityName, needs_remote_access=False):
         if not section_id:
-            section_id = "wba_management" # the default
+            section_id = "Management" # the default
 
         self.page_titles[page_class.identifier()] = title
 
         self.admin_pages[page_class.identifier()] = (page_class, needs_remote_access)
-        icon_path = page_class.identifier()+".png"
-        for sname, stitle, sitems in self.sidebar_sections:
+        icon_path = page_class.identifier() + ".png"
+        for sname, saname, stitle, sitems in self.sidebar_sections:
             if sname == section_id:
-                sitems.append((page_class.identifier(), title, icon_path))
+                sitems.append((page_class.identifier(), accessibilityName, title, icon_path))
                 break
 
     def show_in_sidebar(self):
@@ -362,19 +363,13 @@ class AdministratorContext:
             else:
                 server_version = None
             self.shown_in_sidebar = True
-            first = True
             self.disabled_pages = {}
-            for sname, stitle, sitems in self.sidebar_sections:
-                flags = mforms.TaskSectionShowConfigButton if sname == "wba_instance" else mforms.TaskSectionPlain
-                if first:
-                    flags |= mforms.TaskSectionToggleModeButton
-                    first = False
-                if grt.root.wb.options.options['DbSqlEditor:SidebarModeCombined'] == 1:
-                    flags |= mforms.TaskSectionToggleModeButtonPreSelected
+            for sname, saname, stitle, sitems in self.sidebar_sections:
+                flags = mforms.TaskSectionShowConfigButton if sname == "Instance" else mforms.TaskSectionPlain
 
-                self.sidebar.add_section(sname, stitle, flags)
-                for ident, ititle, icon_path in sitems:
-                    self.sidebar.add_section_entry(sname, ident, ititle, icon_path, mforms.TaskEntryAlwaysActiveLink)
+                self.sidebar.add_section(sname, saname, stitle, flags)
+                for ident, ianame, ititle, icon_path in sitems:
+                    self.sidebar.add_section_entry(sname, ident, ianame, ititle, icon_path, mforms.TaskEntryAlwaysActiveLink)
                     mod, requires_remote_access = self.admin_pages.get(ident, (None, True))
                     enabled = True
                     if requires_remote_access and (not self.server_profile or (self.server_profile and not self.server_profile.is_local and not self.server_profile.remote_admin_enabled)):
@@ -402,7 +397,7 @@ def attachToSQLEditor(name, sender, args):
         context = AdministratorContext(sender)
         sender.customData["adminContext"] = grt.togrt(context)
         if sender.isConnected <= 0:
-            ignore = mforms.Utilities.add_timeout(0.1, lambda:context.open_into_section("admin_server_status", True))
+            ignore = mforms.Utilities.add_timeout(0.1, lambda: context.open_into_section("admin_server_status", True))
             del ignore
 
 #-------------------------------------------------------------------------------
@@ -418,8 +413,8 @@ def initialize():
 
     # register ourselves for when SQL Editor tabs are opened
     nc = NotificationCenter()
-    nc.add_observer(attachToSQLEditor, name = "GRNSQLEditorOpened")
-    nc.add_observer(handleReconnect, name = "GRNSQLEditorReconnected")
+    nc.add_observer(attachToSQLEditor, name="GRNSQLEditorOpened")
+    nc.add_observer(handleReconnect, name="GRNSQLEditorReconnected")
 
     return 1
 
@@ -580,14 +575,17 @@ class PasswordExpiredDialog(mforms.Form):
         vbox.add(hbox, False, True)
 
         self.old_password = mforms.newTextEntry(mforms.PasswordEntry)
+        self.old_password.set_name("Old Password")
         box.add(newLabel("Old Password:", True), 0, 1, 0, 1, mforms.HFillFlag|mforms.VFillFlag)
         box.add(self.old_password, 1, 2, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
 
         self.password = mforms.newTextEntry(mforms.PasswordEntry)
+        self.password.set_name("New Password")
         box.add(newLabel("New Password:", True), 0, 1, 1, 2, mforms.HFillFlag|mforms.VFillFlag)
         box.add(self.password, 1, 2, 1, 2, mforms.HFillFlag|mforms.HExpandFlag)
 
         self.confirm = mforms.newTextEntry(mforms.PasswordEntry)
+        self.confirm.set_name("Confirm Password")
         box.add(newLabel("Confirm:", True), 0, 1, 2, 3, mforms.HFillFlag|mforms.VFillFlag)
         box.add(self.confirm, 1, 2, 2, 3, mforms.HFillFlag|mforms.HExpandFlag)
 
@@ -618,13 +616,13 @@ class PasswordExpiredDialog(mforms.Form):
             old_multi_statements = con.parameterValues.get("CLIENT_MULTI_STATEMENTS")
             old_script = con.parameterValues.get("preInit")
             con.parameterValues["CLIENT_MULTI_STATEMENTS"] = 1
-            con.parameterValues["preInit"] = "SET PASSWORD = PASSWORD('%s')" % escape_sql_string(self.password.get_string_value())
+            con.parameterValues["preInit"] = "SET PASSWORD = '%s'" % escape_sql_string(self.password.get_string_value())
             #con.parameterValues["preInit"] = "ALTER USER '%s'@'%s' IDENTIFIED BY '%s'" % (con.parameterValues["userName"], con.hostIdentifier.replace("Mysql@", ""), escape_sql_string(self.password.get_string_value()))
             #change_pw = "ALTER USER '%s'@'%s' IDENTIFIED BY '%s'" % (con.parameterValues["userName"], con.hostIdentifier.replace("Mysql@", ""), escape_sql_string(self.password.get_string_value())) 
             retry = False
             result = 1
 
-            c = MySQLConnection(con, password = self.old_password.get_string_value())
+            c = MySQLConnection(con, password=self.old_password.get_string_value())
             # connect to server so that preInitScript will do the password reset work
             try:
                 log_info("About to connecto to MySQL Server to change expired password")
@@ -680,14 +678,14 @@ def testInstanceSettingByName(what, connection, server_instance):
         log_info("Instance test: Connecting to %s\n" % profile.ssh_hostname)
 
         try:
-            test_ssh_connection = wb_admin_control.WbAdminControl(profile, None, connect_sql=False, test_only = True)
+            test_ssh_connection = wb_admin_control.WbAdminControl(profile, None, connect_sql=False, test_only=True)
             test_ssh_connection.init()
-                
+
             grt.send_info("connected.")
         except Exception, exc:
-            log_error("Exception: %s" % exc.message)
+            log_error("Exception: %s\n" % exc.message)
             import traceback
-            log_debug2("Backtrace was: " % traceback.format_stack())
+            log_debug2("Backtrace was: ", traceback.format_stack())
             return "ERROR "+str(exc)
         except:
             return "ERROR"
@@ -695,7 +693,8 @@ def testInstanceSettingByName(what, connection, server_instance):
         try:
             test_ssh_connection.acquire_admin_access()
         except Exception, exc:
-            log_error("Exception: %s" % exc.message)
+            
+            log_error("Exception: %s\n" % exc.message)
             import traceback
             log_debug2("Backtrace was: " % traceback.format_stack())
             return "ERROR "+str(exc)
@@ -727,7 +726,7 @@ def testInstanceSettingByName(what, connection, server_instance):
         config_file = profile.config_file_path
         print "Check if %s exists in remote host" % config_file
         try:
-            if not test_ssh_connection.ssh.file_exists(config_file):
+            if not test_ssh_connection.ssh.fileExists(config_file):
                 return "ERROR File %s doesn't exist" % config_file
             else:
                 print "File was found in expected location"
@@ -776,23 +775,23 @@ def testInstanceSettingByName(what, connection, server_instance):
 
     elif what == "check_admin_commands":
         path = profile.start_server_cmd
-        cmd_start= None
+        cmd_start = None
         if path.startswith("/"):
             cmd_start = path.split()[0]
-            if not test_ssh_connection.ssh.file_exists(cmd_start):
+            if not test_ssh_connection.ssh.fileExists(cmd_start):
                 return "ERROR %s is invalid" % path
 
         path = profile.stop_server_cmd
         if path.startswith("/"):
             cmd = path.split()[0]
-            if cmd != cmd_start and not test_ssh_connection.ssh.file_exists(cmd):
+            if cmd != cmd_start and not test_ssh_connection.ssh.fileExists(cmd):
                 return "ERROR %s is invalid" % path
 
         return "OK"
 
     elif what == "check_admin_commands/local":
         path = profile.start_server_cmd
-        cmd_start= None
+        cmd_start = None
         if path.startswith("/"):
             cmd_start = path.split()[0]
             if not os.path.exists(cmd_start):
@@ -828,7 +827,7 @@ def testInstanceSettings(server_instance):
 
 ##------------------------------------------------------------------------------------------------------------------------
 
-@ModuleInfo.plugin("wb.admin.open_into", type="standalone", input=[wbinputs.currentSQLEditor(), wbinputs.string()])
+@ModuleInfo.plugin("wb.admin.open_into", type="standalone", input=[wbinputs.currentSQLEditor(), wbinputs.string()], accessibilityName="Open Into")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_Editor, grt.STRING)
 def openAdminSection(editor, section):
     context = grt.fromgrt(editor.customData["adminContext"])
@@ -841,7 +840,7 @@ def openAdminSection(editor, section):
 # Hack to make this plugin only appear if SE modules are available
 try:
     import wba_meb # noqa
-    @ModuleInfo.plugin("wb.admin.open_into_se", type="standalone", input=[wbinputs.currentSQLEditor(), wbinputs.string()])
+    @ModuleInfo.plugin("wb.admin.open_into_se", type="standalone", input=[wbinputs.currentSQLEditor(), wbinputs.string()], accessibilityName="Open Into")
     @ModuleInfo.export(grt.INT, grt.classes.db_query_Editor, grt.STRING)
     def openAdminSectionSE(editor, section):
         context = grt.fromgrt(editor.customData["adminContext"])
@@ -853,7 +852,7 @@ except ImportError:
     pass
 
 
-@ModuleInfo.plugin("wb.admin.settings", type="standalone", input=[wbinputs.currentSQLEditor()])
+@ModuleInfo.plugin("wb.admin.settings", type="standalone", input=[wbinputs.currentSQLEditor()], accessibilityName="Settings")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_Editor)
 def openConnectionSettings(editor):
     grt.modules.Workbench.showInstanceManagerFor(editor.connection)
@@ -862,7 +861,7 @@ def openConnectionSettings(editor):
         context.refresh_admin_links()
 
 
-@ModuleInfo.plugin("wb.admin.reset_password_cache", type="standalone", input=[wbinputs.currentSQLEditor()])
+@ModuleInfo.plugin("wb.admin.reset_password_cache", type="standalone", input=[wbinputs.currentSQLEditor()], accessibilityName="Reset Password Cache")
 @ModuleInfo.export(grt.INT, grt.classes.db_query_Editor)
 def resetPasswordCache(editor):
     context = grt.fromgrt(editor.customData["adminContext"])
